Murano applications
===================

Files for Murano benchmarking

Structure
---------

* <application_name>/ directories. Each directory store a simple Murano package
  for environment deployment in Murano context. Also there can be other files
  needs for application.


Useful links
------------

* `More about Murano package <https://wiki.openstack.org/wiki/Murano/Documentation/How_to_create_application_package>`_
